function [F, Fdash, FR, mstar, Re, mdot, W_pumpTP, Ah] = db_analysis5(UL, R, Dh, fp, Wp, WH, nSerp, kdelta, Cb, ext_LD)
% function [F, Fdash, FR, mstar, Re, mdot, W_pumpTP, Ah] = db_analysis5(UL, R, Dh, fp, Wp, WH, isSerp, kdelta, Cb, ext_LD)
% a Duffie & Beckman analysis of plate efficiency etc
% UL = collector overall loss coefficient
% kdelta = [metal conductivity  thickness]
%
% Version 2 now with WH and isSerp = 0 for microchannel, =1 for serpentine
% version 3 includes turbulent calc'n and kdelta
% version 4 use nSerp = 0 (microchannel), >0 (number of serpentine tube
% panels in parallel).  WH = total panel area, WH(1)/nSerp = width of one
% section.
% 4a does PDE solution for microchannel Fdash
% v5 gets rid of old code and expects kdelta to have a delta for each Dh

% Assume small Ul, high metal conductivity so m -> 0 and F =1
if nargin<8, kdelta = [Inf 0.001]; end
if nargin<9, Cb = Inf; end
if nargin<10, ext_LD = []; end

nD = size(Dh); nW = size(Wp);
if any(nD>nW)
    if ~all(nW==1), error('Vectors are different sizes'); end
    Wp = repmat(Wp, nD);
elseif any(nW>nD)
    if ~all(nD==1), error('Vectors are different sizes'); end
    Dh = repmat(Dh, nW);
    nD = nW;
end
nD = prod(nD); % convert [1 99] into 99
if size(kdelta,1)==1, kdelta = repmat(kdelta, [nD 1]); end
Re_guess = 2000;
Ah = zeros([nD 1]); F = Ah; Fdash = Ah; FR = Ah; mstar = Ah; Re = Ah; mdot = Ah; W_pumpTP = zeros([nD,2]);
for i = 1:nD  % include laminar here to model bend losses
    [F(i), Fdash(i), FR(i), mstar(i), Re(i), mdot(i), W_pumpTP(i,:), Ah(i)] = db_analysis_turb(Cb, UL, R, Dh(i), fp, Wp(i), WH, kdelta(i,:), nSerp, Re_guess, ext_LD);
    Re_guess = Re(i);
end



%===============================================
%-----------------------------------------------
function [F, Fdash, FR, mstar, Re_Wp, mdot, W_pumpTP, Ah] = db_analysis_turb(Cb, UL, R, Dh, fp, Wp, WH, kdelta, nSerp, Re_guess, ext_LD)
% all inputs are scalar


if nSerp
    L = R * prod(WH)/(nSerp*Dh);
    N = nSerp;
    nbends = max(L/WH(2) - 1, 0);
    %disp('Warning, no bends!!!')
else  % microchannel
    N = R * WH(1) / Dh;
    L = WH(2);
    nbends = 0;
end
panel_LDN = [L Dh N];

% solve to find Re that gives Wp (searches both laminar & turbulent)
%opt = optimset('tolx', 0.0003);
%Re_Wp = fzero(@(x) match_wp(x, panel_LDN, fp, Wp*prod(WH)), Re_guess, opt);
%Re_Wp = fzero(@(x) match_wp(x, panel_LDN, fp, Wp*prod(WH)), [1000 1e5], opt);
% disp([Re_guess Re_Wp])

Re_Wp = match_wp2(Re_guess, ext_LD, panel_LDN, fp, nbends, Wp*prod(WH)); % looks at total power if ext_LD is set
% get mdot and Ah at this Reynolds Number:
[mdot, DP, W_pumpTP, Ah, f, Nu] = get_mdot(Re_Wp, ext_LD, panel_LDN, fp, nbends);

pRh = Ah / prod(WH); % pi*R*h in the Fdash formula


P = Dh ./ R;  % pipe pitch, as D&B page 257, Dh is a vector, R scalar  (not from WH !!)
if nSerp
    m = sqrt(UL ./ prod(kdelta));  % D&B eqn 6.5.4a
    D = Dh + 2*kdelta(2);  % tube OD, assume tube wall = plate thickness
    D = min(D, P);  % avoid D>W
    if m>0
        mPD2 = m .* (P - D)/2; % may be zero if D>W above
        F = tanh(mPD2)./mPD2;
        F(mPD2<=0) = 1;
    else
        F = ones(size(Dh));
    end
    Fdash = 1 ./ (UL.*P.*(1./(UL.*(D + (P-D).*F)) + 1./Cb + 1./(pi*fp.k*Nu)));  % D&B 6.5.18
    FP = NaN;
else
    % assume passages are square, a=b=Dh
    % Must have some Tf-Ta else qu = 0
    F = NaN;
    shape.ab =  Dh*[1 1];
    shape.centre = [0 0];
    shape.type = 'rect';
    show = 0;
    r = (pi/4) * R; % square passage a/p, e.g. 0.5 or 0.75
    p = Dh./r;
    ts = (p-r)/2;
    tt = (kdelta(2)-Dh)/2;
    shape.pdelta = [p kdelta(2)];
    shape.c = kdelta(1);  % metal cond
    conditions.S = 0;  % W/m^2, doesn't matter
    conditions.UL = UL;
    conditions.hi = fp.k*Nu/Dh;
    conditions.Ta = -40;
    conditions.Tf = 0;
    if isinf(shape.c)
        Fdashi = 1; Fdash = 1;
    else
        [Fdashi, Fdash] = fdash_pde2(shape, conditions, show);
    end
end

% find m*
mstar = mdot * fp.c / (prod(WH)*UL*Fdash);
Fddash = mstar * (1 - exp(-1/mstar));
FR = Fddash * Fdash;


