function fp = fluid_properties(fname, conc, TdegC)
% fp = fluid_properties(fname, conc, TdegC)
% was [rho, Cp, mu, k, Pr, th_diff, th_prod] = fluid_properties(fname, conc, TdegC)
% Wrapper for various functions of fluid properties
%   water
%   e-glycol, conc = 0 (water) to 1 (pure EG), data at 50 & 100%
%   tyfocor-ls
%   paratherm-hr
%   paratherm-mr
%   dow550
%   duratherm-630


fname = lower(fname);
if strcmp(fname, 'e-glycol')
    if isempty(conc), error('Mass fraction of glycol must be defined'); end
    % OK now
    [rho, Cp, mu, k] = e_glycol(TdegC, conc);
else
    if ~isempty(conc), 
        error('Don''t specify ''conc'' unless it is ethylene glycol, use []'); 
    end
    if strcmp(fname, 'water')
        % OK now; some values around 0.1% different to e-glycol equivalent
        [rho, Cp, mu, k] = water_props(TdegC);
    elseif strcmp(fname, 'tyfocor-ls')
        % OK
        [rho, Cp, mu, k] = tyfocor_ls(TdegC);
        
    elseif strcmp(fname, 'paratherm-hr')
        [rho, Cp, mu, k] = paratherm('hr', TdegC);
        
    elseif strcmp(fname, 'paratherm-mr')
        [rho, Cp, mu, k] = paratherm('mr', TdegC);        
        
    elseif strcmp(fname, 'dow550')
        % -29 to 99 C for viscosity, 0 to 200 for Cp
        [rho, Cp, mu, k] = dc550(TdegC);
    elseif strcmp(fname, 'duratherm-630')
        % -29 to 99 C for viscosity, 0 to 200 for Cp
        [rho, Cp, mu, k] = dura630(TdegC);
    else
        error('Fluid not recognised')
    end
end

Pr = Cp .* mu ./ k;
th_diff = k ./ (rho.*Cp);          % thermal diffusivity
th_prod = sqrt(rho .* Cp .* k);  % thermal product

fp.c = Cp;
fp.k = k;
fp.mu = mu;
fp.rho = rho;
fp.th_diff = th_diff;
fp.th_prod = th_prod;
fp.Pr = Pr;
fp.TC = TdegC;
fp.Type = fname;
fp.Conc = conc;

