function [f, Nu] = gnielinski(Pr, Re, PoNuH)
% function [f, Nu] = gnielinski(Pr, Re, PoNucf)
% get [f, Nu] using laminar or turbulent correlations
% default PoNucf = [16, 4.36] for laminar conditions, circular hole
% Must set ch = 1 (fluids gets cooled) or 2 (gets heated)
%
% Re should be a column vector
% linear interpolation in transitional region between Re = 2000 and 4000 points.
% NB: some code will "hide" Po & Nucf as fields in fp (fluid properties)

if nargin<3, 
    PoNuH = [16 4.36]; 
elseif ~all(size(PoNuH)==[1 2]),
    error('PoNucf must be 1*2');
end


S = friction_factors(Re, 0, PoNuH(1));  % 0 for smooth pipe
f = S.Petukhov;

trans_start = 2000;
trans_end = 3000;  % Reynolds number at end of transition
ftrans_end = 0.25 ./ (0.79*log(trans_end)-1.64).^2;  % Petunkhov formula

szRe = size(Re);

Nu_lam = repmat(PoNuH(2), szRe); % constant Nu in laminar region
Nu_lamlimit = Nu_lam;

Nu_turb = gnielf(f, Pr, Re);
Nu_turblimit = repmat(gnielf(ftrans_end, Pr, trans_end), szRe);

[fleft, fminus, fplus, fright] = interp_fac(trans_start, trans_end, Re);
Nu = fleft.*Nu_lam + fminus.*Nu_lamlimit + fplus.*Nu_turblimit + fright.*Nu_turb;


%=================================================================================

function Nu = gnielf(f, Pr, Re)
Nu = (f/2).*(Re-1000).*Pr ./...
    (1 + 12.7*(Pr.^(2/3)-1).*sqrt(f/2));



