function [rpos, raxis, linlog, xylist] = multaxp(axlist, utype, xy);
% function [rpos,raxis,linlog,xylist]=multaxp(axlist,utype, xy)
% OR function [rpos, raxis, linlog] = multaxp(axlist, utype): Real axis limits and coord conversion.
%
% Use multaxp to return REAL axes position rpos, REAL axis limits (raxis) and 
% lin/log flag linlog = [0 0] for linear.
% This is useful as it knows about axis('square'), axis('equal'), and axis([? ? ? inf])
% Call as [rpos, raxis, linlog] = multaxp(ax1, utype) where utype must be 'paper' or
% 'screen'. If using log axes, raxis will be log of values (unlike axis itself).
% rpos, raxis and linlog will then have a row for each handle in axlist.
% 
% Can also use for converting coordinates in one axes to the equivalent (same position
% on screen, or on paper) coordinates for a different axes, so can (for instance) zoom
% two overlapping axes, or convert ginputui figure-normalised coordinates to the required
% axes data units. Axis positions are assumed to be normalised.
% To do this, use 'full' syntax (including xy and xylist): first element in axlist
% corresponds to axes in which xy is defined. xylist then has a pair of columns for each 
% row in axlist corrresponding to the two input columns xy = [x y].
%
% Normalised figure position can be obtained by including 1 in the axlist.
%
% Can use normalized instead of data units by including a 'normal' line in
% utype.  For conversion from data to normalised units, call multaxp in
% data units and then call sccoor with raxis and [linlog(input,:); 0 0].
% For conversion from normalised to data, call multaxp with 'normal' in utype, and then
% call sccoor with raxis and [0 0; linlog(output,:)].  
% Roger Moss

% Written by Roger Moss, January 1994.

utypes = ['paper ';'screen';'normal';'data  '];
uname = ['inches';'pixels'];
if nargin<2, error('Must specify conversion on screen or paper'); end

lu = size(utype,1);
for i=1:lu,
   ut(i) = textfind(utypes, utype(i,:));
end
if lu==1, ut(2) = 4; end	% data is default input unit.
ut = sort(ut);
if ~any(ut(1)==[1 2]), error('Use "screen" or "paper" as argument utype'); end
uname = uname(ut(1),:);

GCA = gca;

axlist = axlist(:);
n = length(axlist);
rpos = zeros(n, 4);
raxis = zeros(n, 4);
linlog = logical(zeros(n,2));
%-------------------------------------------------------------------------------------
% In general one has an axes at normalised position (wrt figure window) of rpos =
% [bottom, left, width, height] (as pos) and with axis limits raxis, which are log10 of
% values if using log scales.  The problem is to find these if using axis('square') or 'equal'.
% A further problem is that the axes box position will have different normalised unit positions
% depending on whether it is defined relative to the screen or paper figure positions; if we 
% are calculating pixel positions in terms of get(gcf,'pos') and [rpos, raxis] we must use
% different values of [rpos, raxis] to those we would use if defining positions in inches on paper.
% For movemm, arrow and symdraw, want paper units, so will default to this.


for i = 1:n,
   ax = axlist(i);
   %  uni = get(ax,'units');  ASSUME NORMALISED.
   if ax==1,			% a figure window
      rpos(i,:) = [0 0 1 1]; 
      raxis(i,:) = [0 1 0 1];
   else
      %---------
      % check 2-D non-rotated:
      if any(get(ax, 'view')~=[0 90]), error('Multaxp does not understand 3-D or rotated axes!'); end
      % (1) get axes position:
      GCFI = get(ax,'parent'); 
      GCF(i) = GCFI;
      % don't suppose anyone will ever use on axes that don't have same parent figure,
      % but will give sensible results if they do!
      figp0 = get(GCFI,'Position');
      if ut(1)==1,		% paper
         figp=get(GCFI, 'PaperPosition');
      else
         figp = figp0;
      end
      axp = get(ax,'Position');
      axpf=axp.*figp([3 4 3 4]);
      Data_Asp = get(ax,'DataAspectratio');
      UseData_Asp = strcmp(get(ax,'DataAspectratiomode'),'manual');
      PBox_Asp = get(ax,'PlotBoxAspectratio');
      UsePBox_Asp = strcmp(get(ax,'PlotBoxAspectratiomode'),'manual');
      linlog(i,:) = logical([strcmp(get(ax,'xscale'), 'log'), strcmp(get(ax,'yscale'), 'log')]);
      %-------------------------------------------
      if ~UsePBox_Asp,	
         rpos(i,:) = axp;
      else
         wh2 = min([axpf(3:4); axpf(4)*PBox_Asp(1)/PBox_Asp(2),  axpf(3)*PBox_Asp(2)/PBox_Asp(1)])/2;
         cp = axpf(1:2)+axpf(3:4)/2;	% position within fig box of centre of axes.
         rpos(i,:) = [cp-wh2 2*wh2];	% position in inches or pixels
         rpos(i,:) = rpos(i,:)./figp([3 4 3 4]);	% back to normalised units.
      end
      %--------------------------------------------
      % (2) get axes limits:
      raxis(i,:) = [get(ax,'XLim'),  get(ax,'YLim')];
      if ~any(isinf(raxis(i,:))),	% not semi-auto scaling
         axd = get(ax, 'YDir');
         if strcmp(axd, 'reverse'), raxis(i,:) = raxis(i,[1 2 4 3]); end  
         axd = get(ax, 'XDir');
         if strcmp(axd, 'reverse'), raxis(i,:) = raxis(i,[2 1 3 4]); end  
         if linlog(i,1), raxis(i, [1 2]) = log10(raxis(i, [1 2])); end
         if linlog(i,2), raxis(i, [3 4]) = log10(raxis(i, [3 4])); end
         %-------------------------------
      else	% Oh dear, it is 'equal'....cannot calculate limits, must measure them somehow:
         % For paper position, must set figure position (in inches units)=PaperPosition for 
         % it to be wysiwyg.  Set vis off as may be larger than screen size.
         % This is slow , unfortunately, as creating & deleting a pair of text objects
         % to get relationship between data and normalised units always forces a figure redraw
         % even if nothing else changes.
         if ut(1)==1,set(GCFI,'vis','off', 'units', uname, 'position', figp);end
         axes(ax);
         h=text('units','norm','pos',[0 0 0]);
         h(2)=text('units','norm','pos',[1 1 0]);
         % when converting to inches units, it is the equivalent of the DATA position that
         % is returned...
         set(h,'units', 'data'); posd = [get(h(1),'pos'); get(h(2), 'pos')]; posd = posd(:,[1 2]);
         posd(:,linlog(i,:)) = log10(posd(:,linlog(i,:)));
         set(h,'units', uname);  posu = [get(h(1),'pos'); get(h(2), 'pos')]; posu = posu(:, [1 2]);
         raxwh = rpos(i,3:4).*figp(3:4);
         normp = posu./[raxwh; raxwh];
         xl = table([normp(:,1) posd(:,1)], [0; 1], 1);
         yl = table([normp(:,2) posd(:,2)], [0; 1], 1);
         raxis(i,:) = [xl' yl'];
         delete(h);
         if ut(1)==1,set(GCFI,'units','pixels', 'pos', figp0); end
      end
      %------------------
   end
end
for i = GCF', set(i, 'vis','on'); end
%-----------------------------------------------------------------------------------
%-----------------------------------------------------------------------------------
if nargin>2,		% xy provided
   nxy = size(xy,1);
   xylist = zeros([nxy, 2, n]);
   xylist(:, :, 1) = xy;
   axln = ones(nxy, 1) * raxis(1,:);
   axpn = ones(nxy, 1) * rpos(1,:); 
   if ut(2)==3,		% normalised units
      fnormp = xy.*axpn(:, [3 4]) + axpn(:, [1 2]);
   else			% data units
      xy(:, linlog(1,:)) = log10(xy(:, linlog(1,:))); 
      fnormp = ((xy - axln(:, [1 3])).*axpn(:, [3 4]) ./ (axln(:,[2 4])-axln(:,[1 3]))) + axpn(:, [1 2]);
   end
   %-----------
   for i = 2:n,
      axln = ones(nxy, 1) * raxis(i,:);
      axpn = ones(nxy, 1) * rpos(i,:);
      if ut(2)==3,		% normalised,
         xyi = (fnormp-axpn(:, [1 2]))./axpn(:,[3 4]);
      else			% data
         xyi = ((fnormp-axpn(:, [1 2])).*(axln(:,[2 4])-axln(:,[1 3]))./axpn(:,[3 4])) + axln(:,[1 3]);
         xyi(:,linlog(i,:)) = 10.^xyi(:,linlog(i,:));
      end
      xylist(:, :, i) = xyi;
   end
end
axes(GCA)


