% Optimise a PV-powered system using laminar and turbulent flow equations
% Look at both parallel and series-connected panels.

% 4b with more optimal diameters

set(gcf, 'defaultaxesfontsize', 12, 'defaulttextfontsize', 12,...
    'defaultaxeslinewidth', 1, 'defaultlinelinewidth', 2,...
    'paperunits', 'inches',...
    'paperposition',[0 0 6.4 4], 'papersize', [6.4 4])

clear
G = 1000;
npoints = 200;
Re = logspace(log10(200), 4, npoints)';


Ac = 4;  % [2*pitch, 2/pitch] (parallel), [pitch, 4/pitch] (series)

% assume glass tau = 0.9175 and alpha = 0.95, tau.alpha = 0.87
TauAlpha = 0.87;
UL = 3.8;
TpTa = 40;  % deg C above ambient at inlet
eta0 = TauAlpha - UL*TpTa/G;

% values from plot_radiation_balance_SE.m at (Tp-Ta) = 40
% eta_th = 0.8142;  deta_th = -9.33E-4; These values were for an evacuated
% panel! Silly!

eta_pv = 0.2;
eta_pump = 0.5;

ext_LD = [30 0.02];  % external pipework
isSerp = 1;

fp = fluid_properties('tyfocor-ls', [], 70);
fp.Po = 16; % circular
fp.NuH = 4.36;
%--------------------------------------------------------------
Q=[];
GovE = 3.2;  % gas kWh for cost of electrical kWh
PV_powered = 1;

% microchannel representation of serpentine
WH = [2 2; 1 4; 1 4];
nSerp = [2 1 0]; % parallel, series
Wp = logspace(-2, log10(40), npoints)'/4; % setting total power over a 4 m^2 panel
Dh = [0.01 0.01 0.006];  % for Figure 1 & Table 2
disp('Using Figure 1 values.  Uncomment line 49 to try alternatives for discussion')
% Dh = [0.0144 0.0162 0.006];  % more optimal, for discussion

% disp('trying very small pipe!')
% Dh = [0.006 0.006 0.006];  % for discussion
R = [0.15 0.15 3/pi];


Cb = Inf;

for i = 1:3   % parallel, series, microchannel
    Dhi = repmat(Dh(i), [npoints, 1]);
    if i<3
        kdelta = [222 0.0009];
        %kdelta = [0.52 0.004];
        fp.Po = 16; % circular
        fp.NuH = 4.36;
    else % square
        kdelta = [222 0.008]; % tt = 1 mm, ts = 1 mm
        fp.Po = 14.226; 
        fp.NuH = 3.612;
    end
    [F(:,i), Fdash, FR(:,i), mstar(:,i), Re(:,i), mdot(:,i), W_pumpTP, Ah] = ...
        db_analysis4a(UL, R(i), Dhi, fp, Wp, WH(i,:), nSerp(i), kdelta, Cb, ext_LD);
        
    eta = eta0 * FR(:,i);
    W_elec = W_pumpTP(:,1)/ eta_pump;
    
    A_pv(:,i) = W_elec / (eta_pv * G);
    Q_panel_estd = (Ac - A_pv(:,i))*G*eta0;  % at base efficiency
    theta_bar(:,i) = Q_panel_estd./(2*fp.c*mdot(:,i)); % mean fluid temp rise
    % DT_h(:,i) = Q_panel_estd ./ Ah;
    DT_h(:,i) = Ac * G * eta ./ Ah; % local effect so use whole area
    DT(:,i) = theta_bar(:,i) + DT_h(:,i);
    
    if PV_powered
        if i==1, Q_const_eta = Q_panel_estd + W_elec; end
        Q_panel = G * (Ac - A_pv(:,i)).*eta;
        Q_sum(:,i) = Q_panel + W_elec;
    else  % mains electricity
        if i==1, Q_const_eta = G * Ac .*eta0 + W_elec - GovE*W_elec; end
        Q_panel = G * Ac .*eta;
        Q_sum(:,i) = Q_panel + W_elec - GovE*W_elec;
    end
    
    Wp_tot(:,i) = W_pumpTP(:,1);
    Wp_panel(:,i) = W_pumpTP(:,2);
    
    DTFR = (TauAlpha - eta)*G/UL - TpTa;
    DT(:,i) = DTFR;
end

f = A_pv/Ac;
[maxQ_sum, I] = max(Q_sum);  % I is row number that each came from
maxRe = Re(I);  % for all Dh
for i = 1:3
    Wp_totmax(i) = Wp_tot(I(i),i);  % for 5 mm
    Wp_panelmax(i) = Wp_panel(I(i), i);
    maxmdot(i) = mdot(I(i), i);
    maxDT(i) = DT(I(i), i);
    maxA_pv(i) = A_pv(I(i), i);
end
Wp_totmax
Wp_panelmax
maxmdot
maxDT
maxA_pv


set(gcf,'defaultlinelinewidth', 1.5)
subplot(1,2,1);
yyaxis left
h1L = semilogx(Wp_tot, DT, '-'); grid on
xlabel('Coolant pumping power (W)')
ylabel('T_{pm} - T_i  (\circC)')
%legend(h1L, {'Parallel T','Series T'})
axis([0.01 40 0 60])

yyaxis right
h1R = semilogx(Wp_tot, Re, '--');
ylabel('Reynolds number')
legend([h1L(1); h1R(1)], {'Temperature','Reynolds number'})
axis([0.01 40 0 6000])

subplot(1,2,2)
h2 = semilogx(Wp_tot(:, [1 1 2 3]), [Q_const_eta, Q_sum]); grid
set(h2(1),'linestyle','--')
xlabel('Coolant pumping power (W)')
ylabel('Total heat to coolant (W)')
legs = {'Constant \eta','Parallel','Series','Microchannel'};
legend(h2([1 4 2 3]), legs([1 4 2 3]))
axis([0.1 40 2500 2900])

for i = 1:3,
    set(h1L(i), 'color', get(h2(i+1), 'color'));
    set(h1R(i), 'color', get(h2(i+1), 'color'));
end


so4b.Wp_tot = Wp_tot;
so4b.DT = DT;
so4b.Q_sum = Q_sum;
so4b.Re = Re;

